"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  normalizeExports: () => normalizeExports
});
module.exports = __toCommonJS(src_exports);

// src/normalize.ts
var import_node_fs = require("node:fs");
var import_node_path = __toESM(require("node:path"));

// src/utils.ts
var isNonEmptyArray = (arr) => Array.isArray(arr) && arr.length > 0;
var containsSingleAsterisk = (str) => (str.match(/\*/g) || []).length === 1;

// src/normalize.ts
var defaultConditions = ["node-addons", "node", "import", "require", "default"];
var checkExportsConfiguration = (exports2) => {
  if (typeof exports2 === "object") {
    if (Object.keys(exports2).length === 0) {
      throw new Error("No entries found in exports map");
    }
    if (!Array.isArray(exports2)) {
      const exportsKeys = Object.keys(exports2);
      const keysStartingWithPeriod = exportsKeys.filter((key) => key.startsWith("."));
      if (keysStartingWithPeriod.length !== 0 && keysStartingWithPeriod.length !== exportsKeys.length) {
        throw new Error("Invalid exports configuration");
      }
    }
  }
};
var matchConditions = (exports2, conditions) => {
  if (Array.isArray(exports2)) {
    if (exports2.length === 0) {
      return null;
    }
    let lastError;
    for (const subEntry of exports2) {
      try {
        const value = matchConditions(subEntry, conditions);
        if (typeof value !== "undefined") {
          return value;
        }
      } catch (error) {
        lastError = error;
      }
    }
    if (typeof lastError === "object") {
      throw lastError;
    }
  } else if (exports2 && typeof exports2 === "object") {
    for (const [key, subEntry] of Object.entries(exports2)) {
      if (conditions.has(key)) {
        const value = matchConditions(subEntry, conditions);
        if (typeof value !== "undefined") {
          return value;
        }
      }
    }
  } else if (typeof exports2 === "string" && !exports2.startsWith("./")) {
    throw new Error(`Invalid target '${exports2}'`);
  } else {
    return exports2;
  }
};
var expandWildcardEntry = (wildcardKey, wildcardValue, cwd) => {
  const [wildcardValueBase, wildcardValueTrail] = wildcardValue.split("*");
  const directoryToExpand = import_node_path.default.resolve(cwd, wildcardValueBase);
  if (!(0, import_node_fs.existsSync)(directoryToExpand)) {
    throw new Error(`Directory '${directoryToExpand}' not found`);
  }
  const expandedEntries = {};
  const directoryEntries = (0, import_node_fs.readdirSync)(directoryToExpand, { withFileTypes: true, recursive: true });
  for (const directoryEntry of directoryEntries) {
    if (directoryEntry.isFile()) {
      const expandedPath = import_node_path.default.join(directoryEntry.path, directoryEntry.name);
      const relativeExpandedPath = import_node_path.default.relative(directoryToExpand, expandedPath);
      if (relativeExpandedPath.endsWith(wildcardValueTrail)) {
        const patternMatch = relativeExpandedPath.slice(0, relativeExpandedPath.indexOf(wildcardValueTrail));
        expandedEntries[wildcardKey.replace("*", patternMatch)] = wildcardValue.replace("*", patternMatch);
      }
    }
  }
  return expandedEntries;
};
var expandWildcardEntries = (flattenedEntries, cwd) => {
  let expandedEntries = {};
  const nonWildcardEntries = {};
  const excludedWildcardKeys = [];
  for (const [key, value] of Object.entries(flattenedEntries)) {
    if (key.includes("*") && cwd) {
      if (!containsSingleAsterisk(key)) {
        throw new Error(`Invalid subpath pattern '${key}'`);
      }
      if (value === null) {
        excludedWildcardKeys.push(key);
      } else if (!containsSingleAsterisk(value)) {
        throw new Error(`Multiple '*' in '${value}' are not supported`);
      } else {
        expandedEntries = {
          ...expandedEntries,
          ...expandWildcardEntry(key, value, cwd)
        };
      }
    } else if (value !== null) {
      nonWildcardEntries[key] = value;
    }
  }
  for (const excludedKey of excludedWildcardKeys) {
    const [excludedKeyBase, excludedKeyTrail] = excludedKey.split("*");
    for (const expandedKey of Object.keys(expandedEntries)) {
      if (expandedKey.startsWith(excludedKeyBase) && expandedKey.endsWith(excludedKeyTrail) && excludedKeyBase.length + excludedKeyTrail.length <= expandedKey.length) {
        delete expandedEntries[expandedKey];
      }
    }
  }
  return {
    ...nonWildcardEntries,
    ...expandedEntries
  };
};
var getFlattenedEntries = (exports2, conditions, cwd) => {
  let flattenedEntries = {};
  const singleSubpath = matchConditions(exports2, conditions);
  if (typeof singleSubpath === "string") {
    flattenedEntries["."] = singleSubpath;
  } else {
    for (const [key, subEntry] of Object.entries(exports2)) {
      if (!key.startsWith(".")) {
        continue;
      }
      const value = matchConditions(subEntry, conditions);
      if (value !== void 0) {
        flattenedEntries[key] = value;
      }
    }
  }
  return expandWildcardEntries(flattenedEntries, cwd);
};
var normalizeExports = (exports2, options) => {
  if (!exports2) {
    throw new Error("Exports is not defined");
  }
  checkExportsConfiguration(exports2);
  const { conditions, cwd } = options || {};
  const normalizedExports = getFlattenedEntries(
    exports2,
    new Set(isNonEmptyArray(conditions) ? conditions : defaultConditions),
    cwd
  );
  return normalizedExports;
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  normalizeExports
});
