import { Exports, NormalizeExportsOptions } from './types.js';
/**
 * Normalizes the `"exports"` field of package.json and returns a flattened object.
 *
 * For example, for the below input:
 * ```json
 * {
 *   ".": {
 *     "import": "./dist/esm/index.js",
 *     "default": "./dist/index.js"
 *   },
 *   "./feature": "./dist/feature/index.js"
 * }
 * ```
 * following object is returned:
 * ```json
 * {
 *   ".": "./dist/esm/index.js",
 *   "./feature": "./dist/feature/index.js"
 * }
 * ```
 *
 * @param {Exports} exports Contents of `"exports"` field.
 * @param {NormalizeExportsOptions} options Options for normalization.
 * @returns {Record<string, string>} Normalized exports.
 */
export declare const normalizeExports: (exports: Exports, options?: NormalizeExportsOptions) => Record<string, string>;
